Enum AliasDecision
#[non_exhaustive]pub enum AliasDecision {
None,
Established(NonZeroU16),
New(NonZeroU16),
}Expand description
What to do with the topic alias for an outgoing PUBLISH (3.3.2.3.4).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
None
No alias: send the full topic name.
Established(NonZeroU16)
Reuse an already-established alias: send an empty topic with the alias.
New(NonZeroU16)
First use of a new alias: send the full topic name with the alias, to be
recorded with TopicAliasTable::confirm once the packet is written.